Class: CamaleonCms::Theme
- Inherits:
-
TermTaxonomy
- Object
- TermTaxonomy
- CamaleonCms::Theme
- Defined in:
- app/models/camaleon_cms/theme.rb
Instance Method Summary collapse
-
#settings ⇒ Object
return theme settings configured in config.json.
-
#settings_file ⇒ Object
return the path to the settings file for current theme.
Instance Method Details
#settings ⇒ Object
return theme settings configured in config.json
13 14 15 |
# File 'app/models/camaleon_cms/theme.rb', line 13 def settings PluginRoutes.theme_info(slug) end |
#settings_file ⇒ Object
return the path to the settings file for current theme
18 19 20 |
# File 'app/models/camaleon_cms/theme.rb', line 18 def settings_file File.join(settings['path'], 'views/admin/settings').to_s end |